# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class FilterField(Component):
    """A FilterField component.
Common wrapper for filters/inputs and their labels

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional)

- id (string; optional)

- active (boolean; optional)

- className (string; optional)

- label (string; optional)

- tooltip (string; optional)

- units (string; optional)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, label=Component.UNDEFINED, tooltip=Component.UNDEFINED, units=Component.UNDEFINED, active=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'className', 'label', 'tooltip', 'units']
        self._type = 'FilterField'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'className', 'label', 'tooltip', 'units']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(FilterField, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ModalContextProvider(Component):
    """A ModalContextProvider component.
Use ModalContextProvider to coordinate modal trigger and modal content

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Children will be rendered within the ModalContext. Should contain
    at least a ModalTrigger component and a Modal component.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- active (boolean; optional):
    The current or default state of the modal. If True, the
    \"is-active\" class is added to <Modal/>. This value can be
    watched and changed from outside the component (e.g. via dash
    callback).

- forceAction (boolean; optional):
    Prevent modal from being closed without completion of a specific
    action. If set, there must be a button within the modal that
    updates the \"active\" state using the ModalContext or a dash
    callback on the active prop."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, active=Component.UNDEFINED, forceAction=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'forceAction']
        self._type = 'ModalContextProvider'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'forceAction']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(ModalContextProvider, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class GlobalSearchBar(Component):
    """A GlobalSearchBar component.
Component for rendering advanced search interfaces for data in an API
Renders results in a data table alongside a set of filters that map to properties in the data.

Keyword arguments:

- apiKey (string; optional):
    API key (if needed) that will be used to hit the autocomplete
    route.

- autocompleteFormulaUrl (string; optional):
    Optional URL endpoint for fetching formula autocompletion results
    e.g.
    \"https://api.materialsproject.org/materials/formula_autocomplete/\".

- hidePeriodicTable (boolean; optional):
    Boolean flag for showing/hiding the periodic table on initial
    load.

- placeholder (string; optional):
    Optionally add a string of text to show up in the top-level search
    bar.

- redirectRoute (string; optional):
    The route (minus the query params) that submissions should
    redirect to.

- tooltip (string; optional):
    Optionally add a help icon with a tooltip in the search bar This
    should be used to provide instructions on how to use the search
    bar e.g.  'Type in a comma-separated list of element symbols (e.g.
    Ga, N),  a chemical formula (e.g. C3N), or a material id (e.g.
    mp-10152).  You can also click elements on the periodic table to
    add them to your search.'."""
    @_explicitize_args
    def __init__(self, redirectRoute=Component.UNDEFINED, autocompleteFormulaUrl=Component.UNDEFINED, apiKey=Component.UNDEFINED, hidePeriodicTable=Component.UNDEFINED, tooltip=Component.UNDEFINED, placeholder=Component.UNDEFINED, **kwargs):
        self._prop_names = ['apiKey', 'autocompleteFormulaUrl', 'hidePeriodicTable', 'placeholder', 'redirectRoute', 'tooltip']
        self._type = 'GlobalSearchBar'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['apiKey', 'autocompleteFormulaUrl', 'hidePeriodicTable', 'placeholder', 'redirectRoute', 'tooltip']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(GlobalSearchBar, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class NavbarDropdown(Component):
    """A NavbarDropdown component.
Component for including dropdown menus inside a bulma navbar
Includes all of the default bulma classes for a navbar-dropdown

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Use the children prop to set the dropdown trigger content This can
    be simple text or a component The trigger will automatically be
    wrapped with the \"navbar-link\" class.

- className (string; optional):
    Extra class name applied to top level navbar-item The
    \"navbar-item\" and \"has-dropdown\" classes are added
    automatically.

- isArrowless (boolean; optional):
    Set to True to hide the default angle down arrow created by bulma.

- isRight (boolean; optional):
    Set to True to apply bulma's \"is-right\" class to the
    navbar-dropdown This aligns the dropdown menu with the right side
    of the trigger.

- items (list; optional):
    An array of navbar-items to show in the dropdown when hovering
    over the label. An item can be a link, a menu label, or a divider
    Each item can support the following properties: -- text: string
    (the text to show in the item) -- href: string (the href value for
    link items, ignored if item is menu label) -- isMenuLabel: boolean
    (sets this item as a label with the \"menu-label\" class) --
    isDivider: boolean (sets this item as just a horizontal rule with
    the \"navbar-divider\" class) -- openInNewTab: boolean (will open
    link in a new tab, only works if href is a full url) e.g.
    [           {             text: \"Materials\",             href:
    \"/materials\"           },           {             text:
    \"Molecules\",             href: \"/molecules\"           },
    {             isDivider: True           },           {
    isMenuLabel: True,             text: \"Other\"           },
    {             text: \"External Site\",             href:
    \"https://externalsite.com\",             openInNewTab: True
    }         ]."""
    @_explicitize_args
    def __init__(self, children=None, className=Component.UNDEFINED, isArrowless=Component.UNDEFINED, isRight=Component.UNDEFINED, items=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'className', 'isArrowless', 'isRight', 'items']
        self._type = 'NavbarDropdown'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'className', 'isArrowless', 'isRight', 'items']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(NavbarDropdown, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Navbar(Component):
    """A Navbar component.
Component for including dropdown menus inside a bulma navbar
Includes all of the default bulma classes for a navbar-dropdown

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- brandItem (dict; optional):
    Single navbar-item to display on the left of the navbar in the
    \"navbar-brand\" element. Expects an object that can support all
    the same properties of a navbar-item. e.g.         {
    label: \"The Materials Project\",           href: \"/\",
    image: \"/images/brand.png\"         },.

- className (string; optional):
    Extra class name applied to top level navbar-item. The \"navbar\"
    class is added automatically.

- items (list; optional):
    An array of navbar-items to show on the right side of the navbar.
    An item can be a link, a menu label, or a divider. Each item can
    support the following properties:    className: string;    label:
    string (the text to show in the item);    href: string (the href
    value for link items, ignored if item is menu label);    target:
    string (target value to be added to the link);    icon: string
    (class name(s) for an icon to display in the navbar-item);
    image: string (src attribute of an image to display in the
    navbar-item);    items: array (items to render underneath this
    item as a dropdown)       items of items (i.e. dropdown items) can
    have all the above properties plus the following:       isDivider:
    boolean (sets this item as just a horizontal rule with the
    \"navbar-divider\" class);      isMenuLabel: boolean (sets this
    item as a label with the \"menu-label\" class);      items:
    NavbarItem[];     isRight: boolean (applies bulma's \"is-right\"
    class to the navbar-dropdown    isArrowless: boolean (Set to True
    to hide the default angle down arrow created by bulma); e.g.
    [           {             label: \"API\",             href:
    \"/api\"           },           {             label: \"Help\",
    href: \"/help\"           },           {             label:
    \"Apps\",             isRight: True,             items: [
    {                 label: \"Materials\",                 href:
    \"/materials\"               },               {
    label: \"Molecules\",                 href: \"/molecules\"
    },               {                 isDivider: True
    },               {                 isMenuLabel: True,
    label: \"Other\"               },               {
    label: \"External Site\",                 href:
    \"https://externalsite.com\",                 target: \"_blank\"
    }             ]           }         ]."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, items=Component.UNDEFINED, brandItem=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'brandItem', 'className', 'items']
        self._type = 'Navbar'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'brandItem', 'className', 'items']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Navbar, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class JsonView(Component):
    """A JsonView component.


Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- collapseStringsAfterLength (boolean | number; optional)

- collapsed (boolean | number; optional)

- defaultValue (dict; optional)

- displayDataTypes (boolean; optional)

- displayObjectSize (boolean; optional)

- enableClipboard (boolean; optional)

- groupArraysAfterLength (number; optional)

- iconStyle (string; optional)

- indentWidth (number; optional)

- name (boolean | string; optional)

- sortKeys (boolean; optional)

- src (dict; optional)

- style (dict; optional)

- theme (string; optional)

- validationMessage (string; optional)"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, src=Component.UNDEFINED, name=Component.UNDEFINED, theme=Component.UNDEFINED, style=Component.UNDEFINED, iconStyle=Component.UNDEFINED, indentWidth=Component.UNDEFINED, collapsed=Component.UNDEFINED, collapseStringsAfterLength=Component.UNDEFINED, groupArraysAfterLength=Component.UNDEFINED, enableClipboard=Component.UNDEFINED, displayObjectSize=Component.UNDEFINED, displayDataTypes=Component.UNDEFINED, defaultValue=Component.UNDEFINED, sortKeys=Component.UNDEFINED, validationMessage=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'collapseStringsAfterLength', 'collapsed', 'defaultValue', 'displayDataTypes', 'displayObjectSize', 'enableClipboard', 'groupArraysAfterLength', 'iconStyle', 'indentWidth', 'name', 'sortKeys', 'src', 'style', 'theme', 'validationMessage']
        self._type = 'JsonView'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'collapseStringsAfterLength', 'collapsed', 'defaultValue', 'displayDataTypes', 'displayObjectSize', 'enableClipboard', 'groupArraysAfterLength', 'iconStyle', 'indentWidth', 'name', 'sortKeys', 'src', 'style', 'theme', 'validationMessage']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(JsonView, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DataBlock(Component):
    """A DataBlock component.
Display a single record of data in a horizontal block element
with an optional expanded view to show additional data columns.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Content to display in the bottom section of the card.
    AlternativeWill take precedent.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name(s) to append to the component's default class
    (mpc-data-block).

- columns (list; optional):
    Optional configuration for the columns in the data object. Follows
    the same format as the columns prop in the SearchUI component.

- data (dict; optional):
    Object (i.e. dictionary) of data to be displayed in the block.

- disableRichColumnHeaders (boolean; optional)

- expanded (boolean; optional):
    Control the initial expanded state of the block. @default False.

- footer (a list of or a singular dash component, string or number; optional):
    Content to display in the bottom section of the card. If you want
    to put a component in the footer, add it to the children prop
    instead.

- iconClassName (string; optional):
    Class name(s) to use for the icon in the top right. If no class is
    supplied, there will not be an icon.

- iconTooltip (string; optional):
    Optional tooltip to show when hovering over the icon."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, data=Component.UNDEFINED, columns=Component.UNDEFINED, expanded=Component.UNDEFINED, footer=Component.UNDEFINED, iconClassName=Component.UNDEFINED, iconTooltip=Component.UNDEFINED, disableRichColumnHeaders=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'columns', 'data', 'disableRichColumnHeaders', 'expanded', 'footer', 'iconClassName', 'iconTooltip']
        self._type = 'DataBlock'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'columns', 'data', 'disableRichColumnHeaders', 'expanded', 'footer', 'iconClassName', 'iconTooltip']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DataBlock, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class BibtexButton(Component):
    """A BibtexButton component.
Standardized button for linking to BibTeX.
If no url prop is supplied, a link will be generated
using the doi prop and doi2bib.org.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name(s) to append to the component's default class
    (mpc-bibtex-button) @default 'button is-small'.

- doi (string; optional):
    The DOI (Digital Object Identifier) of the reference to pass to
    doi2bib.org.

- target (string; optional):
    Value to add to the anchor tag's target attribute @default
    '_blank'.

- url (string; optional):
    Directly supply the URL to a reference's bibtex. If supplied, the
    component will not generate its own link using the doi prop."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, doi=Component.UNDEFINED, url=Component.UNDEFINED, target=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'doi', 'target', 'url']
        self._type = 'BibtexButton'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'doi', 'target', 'url']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(BibtexButton, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DownloadButton(Component):
    """A DownloadButton component.
Button for exporting arrays or objects to files

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Use the children prop to set the button content This can be simple
    text or a component.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class(es) to add to the top-level element of the component Note:
    the class \"mpc-download-button\" is always added.

- data (optional):
    Array or object (list or dictionary) to be downloaded If
    downloading as csv or xlsx, data must be an array/list.

- filename (string; optional):
    Name of the file WITHOUT the extension (default: \"export\").

- filetype (a value equal to: 'json', 'csv', 'xlsx'; optional):
    File type to be downloaded This is also the extension that will be
    appended to the filename (default: \"json\").

- tooltip (string; optional):
    Optional tooltip to display above the button on hover."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, data=Component.UNDEFINED, filename=Component.UNDEFINED, filetype=Component.UNDEFINED, tooltip=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'data', 'filename', 'filetype', 'tooltip']
        self._type = 'DownloadButton'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'data', 'filename', 'filetype', 'tooltip']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DownloadButton, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class BibjsonCard(Component):
    """A BibjsonCard component.
Parses a bibjson entry and renders a BibCard
Expects bibjsonEntry in the format used by the bibtexparser library (https://bibtexparser.readthedocs.io/en/v1.1.0/tutorial.html#)

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- bibjsonEntry (boolean | number | string | dict | list; optional):
    A single bib object in bibjson format Only the following bib
    properties are used by this component: title, author (as a list or
    string), year, doi, journal. If any of those properties are
    missing, that property will be omitted from the bibjson result
    card. Any extra properties are simply ignored. e.g.       {
    \"journal\": \"Physical Review X\",         \"year\": \"2015\",
    \"issn\": \"21603308\",         \"isbn\": \"2160-3308\",
    \"doi\": \"10.1103/PhysRevX.5.011006\",         \"author\":
    [\"Agapito, Luis A.\", \"Curtarolo, Stefano\", \"Nardelli, Marco
    Buongiorno\"],         \"title\": \"Reformulation of DFT + U as a
    Pseudohybrid Hubbard Density Functional for Accelerated Materials
    Discovery\",         \"ENTRYTYPE\": \"article\",         \"ID\":
    \"agapito2015\"       }.

- className (string; optional):
    Class name(s) to append to the component's default class.

- preventOpenAccessFetch (boolean; optional):
    Set to True to prevent dynamically fetching a link to a free PDF
    of each reference (using the \"doi\" field for individual bib
    entry). NOTE: the open access URL can also be included in a bib
    entry in the \"openAccessUrl\" property. If set, the URL will not
    be fetched. @default False."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, bibjsonEntry=Component.UNDEFINED, preventOpenAccessFetch=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'bibjsonEntry', 'className', 'preventOpenAccessFetch']
        self._type = 'BibjsonCard'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'bibjsonEntry', 'className', 'preventOpenAccessFetch']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(BibjsonCard, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PublicationButton(Component):
    """A PublicationButton component.
Standardized button for linking to a publication.
If a doi prop or doi.org link is supplied, an open access link
will also be generated next to the publication link.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name(s) to append to the component's default class
    (mpc-open-access-button). Note: the \"tag\" class is the default
    value for className. If you don't want the top-level element to
    have the \"tag\" class, add className=\"\" or any other value. If
    you want to use a bulma tag modifier, use the tagClassName prop
    instead. @default 'tag'.

- doi (string; optional):
    The DOI (Digital Object Identifier) of the publication Will be
    used to generate a doi.org link and to fetch an open access PDF
    link.

- openAccessUrl (string; optional):
    Directly supply the URL to an openly accessible PDF of the
    reference. If supplied, the component will not try to fetch an
    open access URL.

- preventOpenAccessFetch (boolean; optional):
    Set to True to prevent any requests to the open access api. Note
    that if you supply your own openAccessUrl, this prop is not
    necessary.

- tagClassName (string; optional):
    Customize the tag using bulma's tag classes These class names will
    be appended to all of the component's \"tag\" elements.

- target (string; optional):
    Value to add to the anchor tag's target attribute @default
    '_blank'.

- url (string; optional):
    Directly supply the URL to the publication. If a doi.org url is
    supplied, this component will automatically parse the url for the
    doi and use that to fetch an open access link."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, doi=Component.UNDEFINED, className=Component.UNDEFINED, tagClassName=Component.UNDEFINED, url=Component.UNDEFINED, openAccessUrl=Component.UNDEFINED, preventOpenAccessFetch=Component.UNDEFINED, target=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'doi', 'openAccessUrl', 'preventOpenAccessFetch', 'tagClassName', 'target', 'url']
        self._type = 'PublicationButton'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'doi', 'openAccessUrl', 'preventOpenAccessFetch', 'tagClassName', 'target', 'url']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PublicationButton, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DataTable(Component):
    """A DataTable component.
Common wrapper for filters/inputs and their labels

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name(s) to append to the component's default class.

- columns (list; optional):
    An array of column definition objects to control what is rendered
    in the table. See `Column` documentation for specifics on how to
    construct `Column` objects.

- conditionalRowStyles (list; optional):
    List of conditions for styling rows based on a property (selector)
    and a value. Note that this prop currently only supports checking
    for value equivalence (i.e. row[selector] === value). See
    `ConditionalRowStyle` documentation for how to construct
    `ConditionalRowStyle` conditions.

- data (list; optional):
    Array of data objects to display in the table.

- disableRichColumnHeaders (boolean; optional):
    This is a temporary solution to allow SearchUI's to render in
    Storybook. There is an issue with the dynamic column header
    components that causes Storybook to crash. Rendering column
    headers as plain PropTypes.strings fixes the problem. Note that
    this will disable column tooltips and unit labels.

- footer (string; optional):
    Content to display below the table but inside the table's box
    wrapper. Accepts markdown.

- hasHeader (boolean; optional):
    Set to True to show a header with total number of rows and a
    columns selector.

- headerClassName (string; optional):
    Optional class name to apply to the table header.

- pagination (boolean; optional):
    Set to True to paginate the table records.

- paginationIsExpanded (boolean; optional):
    If True, an expanded component will be used for pagination (same
    as in `SearchUI`). If False, a compact version will be used.

- resultLabel (string; optional):
    A noun in singular form to describe what a result represents (e.g.
    \"material\"). This is displayed in the table header.

- resultLabelPlural (string; optional):
    Plural form of the result label. If none supplied, it will
    automatically be the result label plus an \"s\".

- secondarySortAscending (boolean; optional):
    If including a secondarySortField, set whether it should ascend by
    default. True for ascending, False for descending.

- secondarySortField (string; optional):
    Optionally include a secondary sort field. If the sortField ever
    becomes the same as the secondarySortField, the secondary field is
    removed. Must be a valid field and included in your list of
    columns.

- selectableRows (boolean; optional):
    Optionally include/exclude checkboxes next to rows for selecting.

- selectedRows (boolean | number | string | dict | list; optional):
    Property to maintain the state of selected rows so that they are
    accessible via Dash callback.

- sortAscending (boolean; optional):
    If including a sortField, set whether it should ascend by default
    True for ascending, False for descending.

- sortField (string; optional):
    Optionally include a field to sort by on initial load Must be a
    valid field and included in your list of columns."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, data=Component.UNDEFINED, columns=Component.UNDEFINED, sortField=Component.UNDEFINED, sortAscending=Component.UNDEFINED, secondarySortField=Component.UNDEFINED, secondarySortAscending=Component.UNDEFINED, conditionalRowStyles=Component.UNDEFINED, selectableRows=Component.UNDEFINED, selectedRows=Component.UNDEFINED, hasHeader=Component.UNDEFINED, headerClassName=Component.UNDEFINED, resultLabel=Component.UNDEFINED, resultLabelPlural=Component.UNDEFINED, pagination=Component.UNDEFINED, paginationIsExpanded=Component.UNDEFINED, footer=Component.UNDEFINED, disableRichColumnHeaders=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'columns', 'conditionalRowStyles', 'data', 'disableRichColumnHeaders', 'footer', 'hasHeader', 'headerClassName', 'pagination', 'paginationIsExpanded', 'resultLabel', 'resultLabelPlural', 'secondarySortAscending', 'secondarySortField', 'selectableRows', 'selectedRows', 'sortAscending', 'sortField']
        self._type = 'DataTable'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'columns', 'conditionalRowStyles', 'data', 'disableRichColumnHeaders', 'footer', 'hasHeader', 'headerClassName', 'pagination', 'paginationIsExpanded', 'resultLabel', 'resultLabelPlural', 'secondarySortAscending', 'secondarySortField', 'selectableRows', 'selectedRows', 'sortAscending', 'sortField']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DataTable, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class SearchUI(Component):
    """A SearchUI component.
Component for rendering advanced search interfaces for data in an API
Renders results in a data table alongside a set of filters that map to properties in the data.

Documentation: https://materialsproject.github.io/mp-react-components/?path=/docs/search-ui-searchui-component--fully-featured

Keyword arguments:

- id (string; optional)

- apiEndpoint (string; optional)

- apiEndpointParams (dict; optional)

- apiKey (string; optional)

- autocompleteFormulaUrl (string; optional)

- columns (list; optional)

- conditionalRowStyles (list; optional)

- disableRichColumnHeaders (boolean; optional)

- filterGroups (list; optional)

- hasSearchBar (boolean; optional)

- hasSortMenu (boolean; optional)

- isContribs (boolean; optional)

- resultLabel (string; optional)

- results (list; optional)

- searchBarAllowedInputTypesMap (dict; optional)

- searchBarChemicalSystemSelectHelpText (string; optional)

- searchBarElementsSelectHelpText (string; optional)

- searchBarErrorMessage (string; optional)

- searchBarHelpItems (list; optional)

- searchBarPeriodicTableMode (a value equal to: 'toggle', 'focus', 'none'; optional)

- searchBarPlaceholder (string; optional)

- searchBarTooltip (string; optional)

- secondarySortAscending (boolean; optional)

- secondarySortField (string; optional)

- selectableRows (boolean; optional)

- selectedRows (list; optional)

- sortAscending (boolean; optional)

- sortField (string; optional)

- view (a value equal to: 'table', 'synthesis'; optional)"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, columns=Component.UNDEFINED, filterGroups=Component.UNDEFINED, apiEndpoint=Component.UNDEFINED, apiEndpointParams=Component.UNDEFINED, autocompleteFormulaUrl=Component.UNDEFINED, apiKey=Component.UNDEFINED, resultLabel=Component.UNDEFINED, hasSearchBar=Component.UNDEFINED, searchBarTooltip=Component.UNDEFINED, searchBarPlaceholder=Component.UNDEFINED, searchBarErrorMessage=Component.UNDEFINED, searchBarAllowedInputTypesMap=Component.UNDEFINED, searchBarPeriodicTableMode=Component.UNDEFINED, searchBarHelpItems=Component.UNDEFINED, searchBarChemicalSystemSelectHelpText=Component.UNDEFINED, searchBarElementsSelectHelpText=Component.UNDEFINED, hasSortMenu=Component.UNDEFINED, sortField=Component.UNDEFINED, sortAscending=Component.UNDEFINED, secondarySortField=Component.UNDEFINED, secondarySortAscending=Component.UNDEFINED, conditionalRowStyles=Component.UNDEFINED, selectableRows=Component.UNDEFINED, selectedRows=Component.UNDEFINED, view=Component.UNDEFINED, isContribs=Component.UNDEFINED, disableRichColumnHeaders=Component.UNDEFINED, results=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'apiEndpoint', 'apiEndpointParams', 'apiKey', 'autocompleteFormulaUrl', 'columns', 'conditionalRowStyles', 'disableRichColumnHeaders', 'filterGroups', 'hasSearchBar', 'hasSortMenu', 'isContribs', 'resultLabel', 'results', 'searchBarAllowedInputTypesMap', 'searchBarChemicalSystemSelectHelpText', 'searchBarElementsSelectHelpText', 'searchBarErrorMessage', 'searchBarHelpItems', 'searchBarPeriodicTableMode', 'searchBarPlaceholder', 'searchBarTooltip', 'secondarySortAscending', 'secondarySortField', 'selectableRows', 'selectedRows', 'sortAscending', 'sortField', 'view']
        self._type = 'SearchUI'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'apiEndpoint', 'apiEndpointParams', 'apiKey', 'autocompleteFormulaUrl', 'columns', 'conditionalRowStyles', 'disableRichColumnHeaders', 'filterGroups', 'hasSearchBar', 'hasSortMenu', 'isContribs', 'resultLabel', 'results', 'searchBarAllowedInputTypesMap', 'searchBarChemicalSystemSelectHelpText', 'searchBarElementsSelectHelpText', 'searchBarErrorMessage', 'searchBarHelpItems', 'searchBarPeriodicTableMode', 'searchBarPlaceholder', 'searchBarTooltip', 'secondarySortAscending', 'secondarySortField', 'selectableRows', 'selectedRows', 'sortAscending', 'sortField', 'view']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(SearchUI, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class CrossrefCard(Component):
    """A CrossrefCard component.
Parses a crossref entry or fetches a reference from the crossref API and renders a BibCard.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name(s) to append to the component's default class.

- crossrefEntry (boolean | number | string | dict | list; optional):
    A single bib object in crossref format. If a crossEntry is
    supplied, a request will not be made to the crossref API. The
    following bib values are parsed from a Crossref API response:
    title, authors, year, doi, journal.

- errorMessage (string; optional):
    Error message to show inside the card if the crossref request
    fails @default 'Could not find reference'.

- identifier (string; optional):
    Either a DOI or bibtex string to use to search against the
    Crossref /works endpoint. An identifier must be supplied if you
    are not supplying the crossrefEntry directly.

- preventOpenAccessFetch (boolean; optional):
    Set to True to prevent dynamically fetching a link to a free PDF
    of each reference (using the \"doi\" field for individual bib
    entry). NOTE: the open access URL can also be included in a bib
    entry in the \"openAccessUrl\" property. If set, the URL will not
    be fetched. @default False."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, crossrefEntry=Component.UNDEFINED, identifier=Component.UNDEFINED, errorMessage=Component.UNDEFINED, preventOpenAccessFetch=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'crossrefEntry', 'errorMessage', 'identifier', 'preventOpenAccessFetch']
        self._type = 'CrossrefCard'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'crossrefEntry', 'errorMessage', 'identifier', 'preventOpenAccessFetch']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(CrossrefCard, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PeriodicElement(Component):
    """A PeriodicElement component.
This component displays a periodic element

Keyword arguments:

- id (string; optional)

- element (string; optional)

- size (number; optional)"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, size=Component.UNDEFINED, element=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'element', 'size']
        self._type = 'PeriodicElement'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'element', 'size']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PeriodicElement, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class BibjsonFilter(Component):
    """A BibjsonFilter component.
Component for rendering, sorting, and filtering a list of citations in bibjson format
List of bibjson entries are parsed and rendered as BibCards
Expects bibjson in the format used by the bibtexparser library (https://bibtexparser.readthedocs.io/en/v1.1.0/tutorial.html#)

Keyword arguments:
- id (string; optional): The ID used to identify this component in Dash callbacks
- bibjson (list; optional): List of bib objects in bibjson format
Only the following bib properties are used by this component:
 - title
 - author (as a list or string)
 - year
 - doi
 - journal
If any of those properties are missing, that property will be omitted from the bibjson result card.
Any extra properties are simply ignored.
e.g.
        [
          {
            "journal": "Physical Review X",
            "year": "2015",
            "issn": "21603308",
            "isbn": "2160-3308",
            "doi": "10.1103/PhysRevX.5.011006",
            "author": ["Agapito, Luis A.", "Curtarolo, Stefano", "Nardelli, Marco Buongiorno"],
            "title": "Reformulation of DFT + U as a Pseudohybrid Hubbard Density Functional for Accelerated Materials Discovery",
            "ENTRYTYPE": "article",
            "ID": "agapito2015"
          },
          {
            "journal": "Physical Review B",
            "year": "2017",
            "issn": "24699969",
            "doi": "10.1103/PhysRevB.95.174110",
            "author": ["Angsten, Thomas", "Martin, Lane W.", "Asta, Mark"],
            "title": "Orientation-Dependent Properties of Epitaxially Strained Perovskite Oxide Thin Films: Insights from First-Principles Calculations",
            "ENTRYTYPE": "article",
            "ID": "angsten2017"
          }
        ]
- sortField (a value equal to: 'year', 'author', 'title'; optional): Name of property to initially sort bibjson entries by
(default: "year")
- ascending (boolean; optional): Set to true to have the initial sorting direction be ascending
(default: false)
- className (string; optional): Class to add to the top-level element of the component
Note: the class "mpc-bibjson-filter" is always added to the top-level element by default
- resultClassName (string; optional): Class to add to individual result cards
Note: the class "mpc-bibjson-card" is always added to each result by default
- fetchOpenAccessUrl (boolean; optional): Set to true to dynamically fetch a link to a free PDF of
each reference (using the "doi" field for individual bibjson entry)
NOTE: the open access URL can also be included in a bibjson entry
in the "openAccessUrl" property. If set, the URL will not be fetched."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, bibjson=Component.UNDEFINED, sortField=Component.UNDEFINED, ascending=Component.UNDEFINED, className=Component.UNDEFINED, resultClassName=Component.UNDEFINED, fetchOpenAccessUrl=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'bibjson', 'sortField', 'ascending', 'className', 'resultClassName', 'fetchOpenAccessUrl']
        self._type = 'BibjsonFilter'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'bibjson', 'sortField', 'ascending', 'className', 'resultClassName', 'fetchOpenAccessUrl']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(BibjsonFilter, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class CrystalToolkitScene(Component):
    """A CrystalToolkitScene component.


Keyword arguments:

- id (optional):
    The ID used to identify this component in Dash callbacks.

- animation (optional):
    Animation type.

- axisView (optional):
    Where is the axis displayed ( 'NW' / 'NE' / 'SE' / 'SW' / 'HIDDEN'
    ).

- currentCameraState (optional):
    THIS PROP IS SET AUTOMATICALLY Object that maintains the current
    state of the camera. e.g. {   position: {x: 0, y: 0, z: 0},
    quarternion: {x: 0, y: 0, z: 0, w: 0},   zoom: 1,
    setByComponentId: \"1\",   following: True }.

- customCameraState (optional):
    Object for setting the scene to a custom camera state. When
    modified, the camera will update to new custom state. e.g. {
    position: {x: 0, y: 0, z: 0},   quarternion: {x: 0, y: 0, z: 0, w:
    0}, (optional)   zoom: 1 (optional) }.

- data (optional):
    Simple3DScene JSON, the easiest way to generate this is to use the
    Scene class in crystal_toolkit.core.scene and its to_json method.

- debug (optional):
    Display a debug view.

- imageData (optional):
    THIS PROP IS SET AUTOMATICALLY Data string for the image generated
    by imageRequest This string can be downloaded as the filetype
    specified in your imageRequest object.

- imageDataTimestamp (optional):
    THIS PROP IS SET AUTOMATICALLY Date string that represents the
    time imageData was set. This is to prevent race conditions between
    imageRequest and imageData when being used in dash callbacks.

- imageRequest (optional):
    Set to trigger a screenshot or scene download. Must be an object
    with the following structure: {    \"filetype\": \"png\" // the
    image format (\"png\", \"dae\") } Passing this prop as an object
    ensures that new requests are triggered any time the prop is set.

- inletPadding (optional):
    Padding of the axis view.

- inletSize (optional):
    Size of the axis view.

- sceneSize (optional):
    Width / Height of the displayed component.

- selectedObject (optional):
    This points to the last clicked objects. Use it in your dash
    callback to know which objects are currently selected in the
    scene.

- setProps (optional):
    Dash-assigned callback that should be called whenever any of the
    properties change.

- settings (optional):
    Options used for generating scene. Supported options and their
    defaults are given as follows: {    antialias: True, // set to
    False to improve performance    renderer: 'webgl', // 'svg' also
    an option, used for unit testing    transparentBackground: False,
    // transparent background    background: '#ffffff', // background
    color if not transparent,    sphereSegments: 32, // decrease to
    improve performance    cylinderSegments: 16, // decrease to
    improve performance    staticScene: True, // disable if animation
    required    defaultZoom: 1, // 1 will zoom to fit object exactly,
    <1 will add padding between object and box bounds    zoomToFit2D:
    False // if True, will zoom to fit object only along the X and Y
    axes (not Z)    extractAxis: False // will remove the axis from
    the main scene    isMultiSelectionEnabled: False // allow to use
    shift to select,    secondaryObjectView: True // show the selected
    object in a detail view    animation: 'play' | 'slider' | 'none'
    // choose which style of animation is use } There are several
    additional options used for debugging and testing, please consult
    the source code directly for these.

- toggleVisibility (optional):
    Hide/show nodes in scene by its name (key), value is 1 to show the
    node and 0 to hide it."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, settings=Component.UNDEFINED, toggleVisibility=Component.UNDEFINED, imageRequest=Component.UNDEFINED, imageData=Component.UNDEFINED, imageDataTimestamp=Component.UNDEFINED, selectedObject=Component.UNDEFINED, sceneSize=Component.UNDEFINED, axisView=Component.UNDEFINED, inletSize=Component.UNDEFINED, inletPadding=Component.UNDEFINED, debug=Component.UNDEFINED, animation=Component.UNDEFINED, currentCameraState=Component.UNDEFINED, customCameraState=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'animation', 'axisView', 'currentCameraState', 'customCameraState', 'data', 'debug', 'imageData', 'imageDataTimestamp', 'imageRequest', 'inletPadding', 'inletSize', 'sceneSize', 'selectedObject', 'setProps', 'settings', 'toggleVisibility']
        self._type = 'CrystalToolkitScene'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'animation', 'axisView', 'currentCameraState', 'customCameraState', 'data', 'debug', 'imageData', 'imageDataTimestamp', 'imageRequest', 'inletPadding', 'inletSize', 'sceneSize', 'selectedObject', 'setProps', 'settings', 'toggleVisibility']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(CrystalToolkitScene, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Markdown(Component):
    """A Markdown component.
A custom re-worked version of dcc.Markdown.
Uses v6 of react-markdown and applies five plugins
to the markdown component by default:
- remark-gfm
- remark-slug
- remark-highlight.js
- remark-math
- rehype-katex

Keyword arguments:

- children (string | list of strings; optional):
    A markdown string (or array of strings) that adhreres to the
    CommonMark spec.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- className (string; optional):
    Class name of the container element.

- dedent (boolean; optional):
    Remove matching leading whitespace from all lines. Lines that are
    empty, or contain *only* whitespace, are ignored. Both spaces and
    tab characters are removed, but only if they match; we will not
    convert tabs to spaces or vice versa.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- style (dict; optional):
    User-defined inline styles for the rendered Markdown."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, dedent=Component.UNDEFINED, loading_state=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'dedent', 'loading_state', 'style']
        self._type = 'Markdown'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'dedent', 'loading_state', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Markdown, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class BibCard(Component):
    """A BibCard component.
Render bibliographic information in a formatted card view

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- author (string; optional):
    Authors of the reference This string will render as is, so any
    formatting must be done beforehand.

- className (string; optional):
    Class name(s) to append to the component's default class
    (mpc-bib-card).

- doi (string; optional):
    The DOI (Digital Object Identifier) of the reference This
    identifier is used to generate links to the reference's online
    publication, open access PDF, and bibtex.

- journal (string; optional):
    Name of the journal or publisher of the reference.

- openAccessUrl (string; optional):
    Directly supply the URL to an accessible PDF of the reference If
    supplied, the component will not try to fetch an open access URL
    @default undefined.

- preventOpenAccessFetch (boolean; optional):
    Set to True to prevent dynamically fetching a link to a free PDF
    of each reference (using the \"doi\" field for individual bib
    entry). NOTE: the open access URL can also be included in a bib
    entry in the \"openAccessUrl\" property. If set, the URL will not
    be fetched. @default False.

- title (string; optional):
    Title of the reference Will render as a link if doi is supplied.

- year (optional):
    Year of the reference as either a string or number."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, title=Component.UNDEFINED, author=Component.UNDEFINED, year=Component.UNDEFINED, journal=Component.UNDEFINED, doi=Component.UNDEFINED, preventOpenAccessFetch=Component.UNDEFINED, openAccessUrl=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'author', 'className', 'doi', 'journal', 'openAccessUrl', 'preventOpenAccessFetch', 'title', 'year']
        self._type = 'BibCard'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'author', 'className', 'doi', 'journal', 'openAccessUrl', 'preventOpenAccessFetch', 'title', 'year']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(BibCard, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Download(Component):
    """A Download component.


Keyword arguments:

- id (optional):
    The ID used to identify this component in Dash callbacks.

- data (optional):
    When set, a download is invoked using a Blob. Accepts an object
    with the following structure:       {         filename: string;
    content: any;         isBase64: boolean (optional);
    isDataURL: boolean (optional);         mimeType: string (optional,
    default: 'text/plan');       } Properties in data object take
    precedent over component props.

- isBase64 (optional):
    Set to True if data.content is a base64 string.

- isDataURL (optional):
    Set to True if data.content is a data url.

- mimeType (optional):
    Default value for mimeType.

- setProps (optional):
    Dash-assigned callback that should be called to report property
    changes to Dash, to make them available for callbacks."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.UNDEFINED, isBase64=Component.UNDEFINED, isDataURL=Component.UNDEFINED, mimeType=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'data', 'isBase64', 'isDataURL', 'mimeType', 'setProps']
        self._type = 'Download'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'data', 'isBase64', 'isDataURL', 'mimeType', 'setProps']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Download, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MaterialsInput(Component):
    """A MaterialsInput component.
An input field component for searching by mp-id, elements, formula, smiles, or text.
Renders a text input and a periodic table within a PeriodicContext to support two-way binding between the input and periodic table.
i.e. when elements are typed into the field, they are selected in the table,
and when elements are selected in the table, they are appended to the field's input.

Documentation: https://materialsproject.github.io/mp-react-components/?path=/docs/data-entry-materialsinput--multi-type

Keyword arguments:

- id (string; optional)

- allowedInputTypes (list; optional)

- autocompleteApiKey (string; optional)

- autocompleteFormulaUrl (string; optional)

- chemicalSystemSelectHelpText (string; optional)

- className (string; optional)

- debounce (number; optional)

- elementsSelectHelpText (string; optional)

- errorMessage (string; optional)

- helpItems (list; optional)

- hidePeriodicTable (boolean; optional)

- hideWildcardButton (boolean; optional)

- inputClassName (string; optional)

- label (string; optional)

- loading (boolean; optional)

- maxElementSelectable (number; optional)

- periodicTableMode (a value equal to: 'toggle', 'focus', 'none'; optional)

- placeholder (string; optional)

- showSubmitButton (boolean; optional)

- showTypeDropdown (boolean; optional)

- submitButtonClicks (number; optional)

- submitButtonText (string; optional)

- tooltip (string; optional)

- type (a value equal to: 'elements', 'chemical_system', 'formula', 'mpid', 'smiles', 'text'; optional)

- value (string; optional)"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, inputClassName=Component.UNDEFINED, value=Component.UNDEFINED, type=Component.UNDEFINED, allowedInputTypes=Component.UNDEFINED, showTypeDropdown=Component.UNDEFINED, placeholder=Component.UNDEFINED, errorMessage=Component.UNDEFINED, debounce=Component.UNDEFINED, periodicTableMode=Component.UNDEFINED, hidePeriodicTable=Component.UNDEFINED, autocompleteFormulaUrl=Component.UNDEFINED, autocompleteApiKey=Component.UNDEFINED, tooltip=Component.UNDEFINED, helpItems=Component.UNDEFINED, showSubmitButton=Component.UNDEFINED, submitButtonClicks=Component.UNDEFINED, submitButtonText=Component.UNDEFINED, label=Component.UNDEFINED, hideWildcardButton=Component.UNDEFINED, chemicalSystemSelectHelpText=Component.UNDEFINED, elementsSelectHelpText=Component.UNDEFINED, maxElementSelectable=Component.UNDEFINED, loading=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allowedInputTypes', 'autocompleteApiKey', 'autocompleteFormulaUrl', 'chemicalSystemSelectHelpText', 'className', 'debounce', 'elementsSelectHelpText', 'errorMessage', 'helpItems', 'hidePeriodicTable', 'hideWildcardButton', 'inputClassName', 'label', 'loading', 'maxElementSelectable', 'periodicTableMode', 'placeholder', 'showSubmitButton', 'showTypeDropdown', 'submitButtonClicks', 'submitButtonText', 'tooltip', 'type', 'value']
        self._type = 'MaterialsInput'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowedInputTypes', 'autocompleteApiKey', 'autocompleteFormulaUrl', 'chemicalSystemSelectHelpText', 'className', 'debounce', 'elementsSelectHelpText', 'errorMessage', 'helpItems', 'hidePeriodicTable', 'hideWildcardButton', 'inputClassName', 'label', 'loading', 'maxElementSelectable', 'periodicTableMode', 'placeholder', 'showSubmitButton', 'showTypeDropdown', 'submitButtonClicks', 'submitButtonText', 'tooltip', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(MaterialsInput, self).__init__(**args)



from .JsonView import JsonView
from .MatSidebar import MatSidebar
from .CameraContextProvider import CameraContextProvider
from .CrystalToolkitScene import CrystalToolkitScene
from .Download import Download
from .GraphComponent import GraphComponent
from .DataBlock import DataBlock
from .DataTable import DataTable
from .DownloadButton import DownloadButton
from .DownloadDropdown import DownloadDropdown
from .Formula import Formula
from .Markdown import Markdown
from .Modal import Modal
from .ModalContextProvider import ModalContextProvider
from .ModalTrigger import ModalTrigger
from .SearchUI import SearchUI
from .SynthesisRecipeCard import SynthesisRecipeCard
from .Tooltip import Tooltip
from .FilterField import FilterField
from .GlobalSearchBar import GlobalSearchBar
from .MaterialsInput import MaterialsInput
from .Select import Select
from .Dropdown import Dropdown
from .Navbar import Navbar
from .NavbarDropdown import NavbarDropdown
from .Scrollspy import Scrollspy
from .Tabs import Tabs
from .PeriodicContext import PeriodicContext
from .PeriodicContextTable import PeriodicContextTable
from .PeriodicElement import PeriodicElement
from .PeriodicFilter import PeriodicFilter
from .PeriodicTableInput import PeriodicTableInput
from .BibCard import BibCard
from .BibFilter import BibFilter
from .BibjsonCard import BibjsonCard
from .BibtexButton import BibtexButton
from .CrossrefCard import CrossrefCard
from .PublicationButton import PublicationButton

__all__ = [
    "JsonView",
    "MatSidebar",
    "CameraContextProvider",
    "CrystalToolkitScene",
    "Download",
    "GraphComponent",
    "DataBlock",
    "DataTable",
    "DownloadButton",
    "DownloadDropdown",
    "Formula",
    "Markdown",
    "Modal",
    "ModalContextProvider",
    "ModalTrigger",
    "SearchUI",
    "SynthesisRecipeCard",
    "Tooltip",
    "FilterField",
    "GlobalSearchBar",
    "MaterialsInput",
    "Select",
    "Dropdown",
    "Navbar",
    "NavbarDropdown",
    "Scrollspy",
    "Tabs",
    "PeriodicContext",
    "PeriodicContextTable",
    "PeriodicElement",
    "PeriodicFilter",
    "PeriodicTableInput",
    "BibCard",
    "BibFilter",
    "BibjsonCard",
    "BibtexButton",
    "CrossrefCard",
    "PublicationButton"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class SynthesisRecipeCard(Component):
    """A SynthesisRecipeCard component.
Display synthesis recipe data in a standardized card view.

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name(s) to append to the component's default class
    (mpc-data-block).

- data (dict; optional):
    Object (i.e. dictionary) of data to be displayed in the block.
    Data should be in the format returned for a single result from the
    synthesis API endpoint."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, data=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'data']
        self._type = 'SynthesisRecipeCard'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'data']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(SynthesisRecipeCard, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PeriodicContext(Component):
    """A PeriodicContext component.


Keyword arguments:

- children (boolean | number | string | dict | list; optional)

- id (string; optional)

- disabledElements (list; optional):
    A list of symbols to grey-out as disabled.

- enabledElements (list; optional):
    A list of selected symbols.

- forwardOuterChange (boolean; optional):
    Forward external changes.

- hiddenElements (list; optional):
    A list of hidden symbols."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, disabledElements=Component.UNDEFINED, enabledElements=Component.UNDEFINED, hiddenElements=Component.UNDEFINED, forwardOuterChange=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'disabledElements', 'enabledElements', 'forwardOuterChange', 'hiddenElements']
        self._type = 'PeriodicContext'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'disabledElements', 'enabledElements', 'forwardOuterChange', 'hiddenElements']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PeriodicContext, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Dropdown(Component):
    """A Dropdown component.
Generic dropdown menu that can render arbitrary items for display
and navigation purposes only (i.e. not for selecting options or performing actions that are not links)

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Use the children prop to set the dropdown items. This should
    usually be a list of <div> components with the class
    \"dropdown-item\". The content of each item can be anything from
    simple text to a component.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name(s) to append to the component's default class
    (dropdown).

- closeOnSelection (boolean; optional):
    Set to False to keep the menu open when an item is clicked
    @default True.

- isArrowless (boolean; optional):
    Set to True to remove the arrow to the right of the trigger label.

- isRight (boolean; optional):
    Set to True to align the dropdown menu with the right of the
    trigger.

- isUp (boolean; optional):
    Set to True to make the dropdown menu open upwards.

- items (list of strings; optional):
    List of strings to display inside the dropdown menu. Omit this and
    use the children prop instead if you want supply components as
    dropdown items.

- triggerClassName (string; optional):
    Class name(s) to apply to button that opens the dropdown menu
    @default 'button'.

- triggerIcon (string; optional):
    Class name(s) for the icon to display to the left of the trigger
    label (optional).

- triggerLabel (string; optional):
    Text to display in the button that triggers the dropdown to open."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, triggerLabel=Component.UNDEFINED, triggerClassName=Component.UNDEFINED, triggerIcon=Component.UNDEFINED, items=Component.UNDEFINED, isArrowless=Component.UNDEFINED, isUp=Component.UNDEFINED, isRight=Component.UNDEFINED, closeOnSelection=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'closeOnSelection', 'isArrowless', 'isRight', 'isUp', 'items', 'triggerClassName', 'triggerIcon', 'triggerLabel']
        self._type = 'Dropdown'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'closeOnSelection', 'isArrowless', 'isRight', 'isUp', 'items', 'triggerClassName', 'triggerIcon', 'triggerLabel']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Dropdown, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Select(Component):
    """A Select component.
Wrapper component for react-select
This can be used as an alternative to dcc.Dropdown
Automatically adds the wrapper class "react-select-container"
and the class prefix "react-select-" to all the elements created by react-select

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- arbitraryProps (dict; optional):
    Object for placing all other props that are supported by
    react-select but are not explicitly defined here. See
    https://react-select.com/props  This is a workaround because Dash
    components cannot accept props that aren't explicitly defined.
    e.g.         {           'closeMenuOnSelect': False,
    'escapeClearsValue': True          }.

- defaultValue (boolean | number | string | dict | list; optional):
    The default value assigned if no selection is made. (default:
    None).

- isClearable (boolean; optional):
    Determines if dropdown has an 'x' icon for clearing the current
    value. (default: False).

- isMulti (boolean; optional):
    Set to True if select should allow multiple options to be
    selected. (default: False).

- options (list; optional):
    List of objects to be used as options in the dropdown e.g.
    [           {             'label': 'One',             'value': 1
    },           {             'label': 'Two',             'value': 2
    }         ].

- value (boolean | number | string | dict | list; optional):
    The value of the select dropdown. Accepts either the value itself
    or the an entire object from the options array. e.g. 1 or
    {'label': 'One', 'value': 1}."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, options=Component.UNDEFINED, value=Component.UNDEFINED, defaultValue=Component.UNDEFINED, isClearable=Component.UNDEFINED, isMulti=Component.UNDEFINED, arbitraryProps=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'arbitraryProps', 'defaultValue', 'isClearable', 'isMulti', 'options', 'value']
        self._type = 'Select'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'arbitraryProps', 'defaultValue', 'isClearable', 'isMulti', 'options', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Select, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class BibFilter(Component):
    """A BibFilter component.
Component for rendering and filtering a list of citations in bibjson or crossref format
Expects bibjson in the format output by the bibtexparser library (https://bibtexparser.readthedocs.io/en/v1.1.0/tutorial.html#)
Expects crossref in the format returned by the Crossref API

Keyword arguments:

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- ascending (boolean; optional):
    Set to True to have the initial sorting direction be ascending
    @default False.

- bibEntries (list; optional):
    List of bib objects in bibjson or crossref format Only the
    following bib properties are used by this component:  - title  -
    author (as a list or string)  - year  - doi  - journal If any of
    those properties are missing, that property will be omitted from
    the bibjson result card. Any extra properties are simply ignored.

- className (string; optional):
    Class name(s) to append to the component's default class
    (mpc-bib-filter).

- format (a value equal to: 'bibjson', 'crossref'; optional):
    Format of the bibliographoc objects supplied in bibEntries
    @default 'bibjson'.

- preventOpenAccessFetch (boolean; optional):
    Set to True to prevent dynamically fetching a link to a free PDF
    of each reference (using the \"doi\" field for individual bib
    entry). NOTE: the open access URL can also be included in a bib
    entry in the \"openAccessUrl\" property. If set, the URL will not
    be fetched. @default False.

- resultClassName (string; optional):
    Class name(s) to append to individual result cards' default class
    (mpc-bib-card).

- sortField (a value equal to: 'year', 'author', 'title'; optional):
    Name of property to initially sort entries by @default 'year'."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, format=Component.UNDEFINED, bibEntries=Component.UNDEFINED, sortField=Component.UNDEFINED, ascending=Component.UNDEFINED, resultClassName=Component.UNDEFINED, preventOpenAccessFetch=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'ascending', 'bibEntries', 'className', 'format', 'preventOpenAccessFetch', 'resultClassName', 'sortField']
        self._type = 'BibFilter'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'ascending', 'bibEntries', 'className', 'format', 'preventOpenAccessFetch', 'resultClassName', 'sortField']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(BibFilter, self).__init__(**args)



import json
import os
from setuptools import setup


with open('package.json') as f:
    package = json.load(f)

package_name_split = package['name'].split('/')
package_name_without_scope = package_name_split[len(package_name_split) - 1]
package_name = package_name_without_scope.replace(' ', '_').replace('-', '_')

setup(
    name=package_name,
    version=package["version"],
    author=package['author'],
    packages=[package_name],
    include_package_data=True,
    license=package['license'],
    description=package.get('description', package_name),
    install_requires=[],
    classifiers = [
        'Framework :: Dash',
    ],    
)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class OpenAccessLink(Component):
    """An OpenAccessLink component.
Render bibliographic information in a formatted card view

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): Use the children prop to set the inner link content
This can be simple text or a component
- id (string; optional): The ID used to identify this component in Dash callbacks
- className (string; optional): Class to add to the top-level element of the component
- doi (string; optional): The DOI (Digital Object Identifier) of the reference
to attempt to fetch an open access PDF link for
- url (string; optional): Directly supply the URL to an accessible PDF of the reference
If supplied, the component will not try to fetch an open access URL
(default: undefined)
- showLoadingText (boolean; optional): Set to true to show the text "Loading..." inside the link
while the URL is being fetched.
If false, the is-loading is applied to the link while loading.
If supplying the Bulma button class, this will show a spinner icon.
(default: false)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, doi=Component.UNDEFINED, url=Component.UNDEFINED, showLoadingText=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'doi', 'url', 'showLoadingText']
        self._type = 'OpenAccessLink'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'doi', 'url', 'showLoadingText']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(OpenAccessLink, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DownloadDropdown(Component):
    """A DownloadDropdown component.
Dropdown for exporting arrays/lists to json, csv, or xlsx files
The dropdown options are prepopulated as JSON, CSV, EXCEL
This dropdown contains all the classes used in bulma dropdown

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Use the children prop to set the content for the dropdown button
    label This can be simple text or a component.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- buttonClassName (string; optional):
    Class(es) to add to the button element of the component Note: the
    class \"button\" is already added by default.

- className (string; optional):
    Class(es) to add to the top-level element of the component Note:
    the classes \"mpc-download-dropdown dropdown is-active\" are
    already added by default.

- data (optional):
    Array/list to be downloaded.

- filename (string; optional):
    Name of the file WITHOUT the extension (default: \"export\").

- tooltip (string; optional):
    Optional tooltip to display above the button on hover."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, buttonClassName=Component.UNDEFINED, data=Component.UNDEFINED, filename=Component.UNDEFINED, tooltip=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'buttonClassName', 'className', 'data', 'filename', 'tooltip']
        self._type = 'DownloadDropdown'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'buttonClassName', 'className', 'data', 'filename', 'tooltip']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DownloadDropdown, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tabs(Component):
    """A Tabs component.
Custom wrapper for the react-tabs component.
See https://github.com/reactjs/react-tabs

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Use the children prop to set the separate tab contents. Children
    must be a list of elements that is the same length as the list of
    labels in the labels prop. The element's order in the children
    array determines which label it is associated with.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- arbitraryProps (dict; optional):
    Object for placing all other props that are supported by
    react-select but are not explicitly defined here. See
    https://github.com/reactjs/react-tabs  This is a workaround
    because Dash components cannot accept props that aren't explicitly
    defined. e.g.         {           'defaultFocus': True,
    'selectedTabClassName': 'active-tab'          }.

- className (string; optional):
    Class name applied to top level wrapper for tabs and tab content.
    The \"mpc-tabs\" class is added automatically.

- labels (list of strings; optional):
    List of strings to use as labels for the tabs. The number of
    labels must equal the number of children (i.e. tab content items).

- tabIndex (number; optional):
    The current or default tabIndex to be active. This value can be
    watched and changed from outside the component (e.g. via dash
    callback)."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, labels=Component.UNDEFINED, tabIndex=Component.UNDEFINED, arbitraryProps=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'arbitraryProps', 'className', 'labels', 'tabIndex']
        self._type = 'Tabs'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'arbitraryProps', 'className', 'labels', 'tabIndex']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tabs, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Scrollspy(Component):
    """A Scrollspy component.
Component for building in-page navigation menus with scrollspy functionality

Keyword arguments:

- activeClassName (string; optional):
    Class name applied to active links in the menu (default:
    'is-active').

- menuClassName (string; optional):
    Class name applied to the <aside> that contains the whole menu
    (default: 'menu').

- menuGroupLabelClassName (string; optional):
    Class name applied to all menu group labels (default:
    'menu-label').

- menuGroups (list; optional):
    An array of MenuGroup items that is used to build the menu and its
    links. Each MenuGroup has an optional label and a required 'items'
    array of MenuItems. Each MenuItem has a label that is rendered in
    the menu and a targetId that is the id of the element it should
    link to. Do not include '#' in targetId. example:       [
    {label: '...', items: [           {label: '...', targetId: '...'},
    {label: '...', targetId: '...', items: [             {label:
    '...', targetId: '...'}           }]         ]}       ].

- menuItemClassName (string; optional):
    Class name applied to the <li> of each menu item (default: '').

- menuItemContainerClassName (string; optional):
    Class name applied to each <ul> of menu items (default:
    'menu-list').

- offset (number; optional):
    An integer to determine the scroll offset from an item that will
    trigger it active (default: -20)."""
    @_explicitize_args
    def __init__(self, menuGroups=Component.UNDEFINED, activeClassName=Component.UNDEFINED, menuClassName=Component.UNDEFINED, menuGroupLabelClassName=Component.UNDEFINED, menuItemContainerClassName=Component.UNDEFINED, menuItemClassName=Component.UNDEFINED, offset=Component.UNDEFINED, **kwargs):
        self._prop_names = ['activeClassName', 'menuClassName', 'menuGroupLabelClassName', 'menuGroups', 'menuItemClassName', 'menuItemContainerClassName', 'offset']
        self._type = 'Scrollspy'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['activeClassName', 'menuClassName', 'menuGroupLabelClassName', 'menuGroups', 'menuItemClassName', 'menuItemContainerClassName', 'offset']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Scrollspy, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ModalTrigger(Component):
    """A ModalTrigger component.
Render a trigger that opens a ModalContent that is within the same ModalContextProvider

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Children will be rendered as the trigger content.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- className (string; optional):
    Class name applied to the modal trigger span. The
    \"mpc-modal-trigger\" class is added automatically."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className']
        self._type = 'ModalTrigger'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(ModalTrigger, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tooltip(Component):
    """A Tooltip component.
Tooltip component based on react-tooltip (https://github.com/wwayne/react-tooltip).
To attach a Tooltip component to a trigger element,
add the attributes "data-tip" and "data-for" to the trigger element.
The "data-for" attribute's value should be equal to the id of the Tooltip
component you want to connect it to.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Use the children prop to set the content of the tooltip. This can
    be simple text or a component.

- id (string; optional):
    The ID used to identify this component in Dash callbacks.

- border (boolean; optional)

- className (string; optional)

- clickable (boolean; optional)

- delayHide (number; optional)

- delayShow (number; optional)

- disable (boolean; optional)

- effect (string; optional)

- event (string; optional)

- eventOff (string; optional)

- globalEventOff (string; optional)

- html (boolean; optional)

- multiline (boolean; optional)

- offset (dict; optional)

- place (string; optional)

- scrollHide (boolean; optional)

- type (string; optional)"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, place=Component.UNDEFINED, type=Component.UNDEFINED, effect=Component.UNDEFINED, event=Component.UNDEFINED, eventOff=Component.UNDEFINED, globalEventOff=Component.UNDEFINED, offset=Component.UNDEFINED, multiline=Component.UNDEFINED, className=Component.UNDEFINED, html=Component.UNDEFINED, delayHide=Component.UNDEFINED, delayShow=Component.UNDEFINED, border=Component.UNDEFINED, disable=Component.UNDEFINED, scrollHide=Component.UNDEFINED, clickable=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'border', 'className', 'clickable', 'delayHide', 'delayShow', 'disable', 'effect', 'event', 'eventOff', 'globalEventOff', 'html', 'multiline', 'offset', 'place', 'scrollHide', 'type']
        self._type = 'Tooltip'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'border', 'className', 'clickable', 'delayHide', 'delayShow', 'disable', 'effect', 'event', 'eventOff', 'globalEventOff', 'html', 'multiline', 'offset', 'place', 'scrollHide', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tooltip, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class OpenAccessButton(Component):
    """An OpenAccessButton component.
Standardized button for linking to an Open Access PDF.
If no url prop is supplied, a PDF link will be fetched
from the Open Access Button API using the doi prop.

Keyword arguments:
- id (string; optional): The ID used to identify this component in Dash callbacks
- className (string; optional): Class name(s) to append to the component's default class (mpc-open-access-button)
@default 'button is-small'
- doi (string; optional): The DOI (Digital Object Identifier) of the reference
to attempt to fetch an open access PDF link for.
- url (string; optional): Directly supply the URL to an accessible PDF of the reference.
If supplied, the component will not try to fetch an open access URL.
- showLoadingText (boolean; optional): Set to true to show the text "Loading..." inside the link
while the URL is being fetched.
If false, the is-loading is applied to the link while loading.
If supplying the Bulma button class, this will show a spinner icon.
@default false
- target (string; optional): Value to add to the anchor tag's target attribute
@default '_blank'"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, doi=Component.UNDEFINED, url=Component.UNDEFINED, showLoadingText=Component.UNDEFINED, target=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'doi', 'url', 'showLoadingText', 'target']
        self._type = 'OpenAccessButton'
        self._namespace = 'dash_mp_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'doi', 'url', 'showLoadingText', 'target']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(OpenAccessButton, self).__init__(**args)
